'''
Default settings for liaar
'''


# default liaar port number
LIAAR_PORT = 1234

# apps directory
APPS_DIRECTORY = './apps/'

# resources directory
RESOURCES_DIRECTORY = './resources/'

# resource files extension
APP_FILE_EXTENSION = 'json'

# app setting file name
APP_SETTING_FILENAME = 'setting'

# app default url format
APP_URL_FORMAT = '/{app_name}/{version}'

# app's resources default url format
APP_RESOURCE_URL_FORMAT = '/{resource_name}'

# app's methods default url format
APP_METHOD_URL_FORMAT = '/{method_name}'
